@@ -8,13 +8,9 @@ from grai_source_snowflake.adapters import adapt_to_client
 from grai_source_snowflake.loader import SnowflakeConnector
 
 
-def get_nodes_and_edges(
-    connector: SnowflakeConnector, version: Literal["v1"]
-) -> Tuple[List[Node], List[Edge]]:
+def get_nodes_and_edges(connector: SnowflakeConnector, version: Literal["v1"]) -> Tuple[List[Node], List[Edge]]:
     if version != "v1":
-        raise NotImplementedError(
-            f"No available implementation for client version {version}"
-        )
+        raise NotImplementedError(f"No available implementation for client version {version}")
 
     with connector.connect() as conn:
         nodes, edges = conn.get_nodes_and_edges()
@@ -35,7 +31,6 @@ def update_server(
     database: Optional[str] = None,
     schema: Optional[str] = None,
 ) -> None:
-
     conn = SnowflakeConnector(
         account=account,
         user=user,
